@@ -18,9 +18,8 @@ from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
-
-from .literals import SortOrder
+from .literals import SortOrderType
+from .paginator import ListHumanLoopsPaginator
 from .type_defs import (
     DescribeHumanLoopResponseTypeDef,
     HumanLoopDataAttributesTypeDef,
@@ -58,7 +57,7 @@ class Exceptions:
 
 class AugmentedAIRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -67,20 +66,20 @@ class AugmentedAIRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def delete_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
-        [Show boto3-stubs documentation](./client.md#delete-human-loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
+        [Show boto3-stubs documentation](./client.md#delete_human_loop)
         """
 
     def describe_human_loop(self, HumanLoopName: str) -> DescribeHumanLoopResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
-        [Show boto3-stubs documentation](./client.md#describe-human-loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
+        [Show boto3-stubs documentation](./client.md#describe_human_loop)
         """
 
     def generate_presigned_url(
@@ -91,8 +90,8 @@ class AugmentedAIRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_human_loops(
@@ -100,13 +99,13 @@ class AugmentedAIRuntimeClient:
         FlowDefinitionArn: str,
         CreationTimeAfter: datetime = None,
         CreationTimeBefore: datetime = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> ListHumanLoopsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
-        [Show boto3-stubs documentation](./client.md#list-human-loops)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
+        [Show boto3-stubs documentation](./client.md#list_human_loops)
         """
 
     def start_human_loop(
@@ -117,17 +116,17 @@ class AugmentedAIRuntimeClient:
         DataAttributes: HumanLoopDataAttributesTypeDef = None,
     ) -> StartHumanLoopResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
-        [Show boto3-stubs documentation](./client.md#start-human-loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
+        [Show boto3-stubs documentation](./client.md#start_human_loop)
         """
 
     def stop_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
-        [Show boto3-stubs documentation](./client.md#stop-human-loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
+        [Show boto3-stubs documentation](./client.md#stop_human_loop)
         """
 
     def get_paginator(self, operation_name: Literal["list_human_loops"]) -> ListHumanLoopsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
         """
