@@ -23,7 +23,7 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import SortOrder
+from .literals import SortOrderType
 from .type_defs import ListHumanLoopsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListHumanLoopsPaginator",)
@@ -31,7 +31,7 @@ __all__ = ("ListHumanLoopsPaginator",)
 
 class ListHumanLoopsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
     """
 
     def paginate(
@@ -39,10 +39,10 @@ class ListHumanLoopsPaginator(Boto3Paginator):
         FlowDefinitionArn: str,
         CreationTimeAfter: datetime = None,
         CreationTimeBefore: datetime = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListHumanLoopsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
         [Show boto3-stubs documentation](./paginators.md#listhumanloopspaginator)
         """
